@@ -1,12 +1,12 @@
 package Data::Clean::Base;
 
-our $DATE = '2014-12-10'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2015-03-26'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Function::Fallback::CoreOrPP qw(clone);
 use Scalar::Util qw(blessed);
@@ -206,7 +206,7 @@ Data::Clean::Base - Base class for Data::Clean::*
 
 =head1 VERSION
 
-This document describes version 0.20 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2014-12-10.
+This document describes version 0.21 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2015-03-26.
 
 =for Pod::Coverage ^(command_.+)$
 
@@ -357,7 +357,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
