@@ -1,13 +1,14 @@
 package Data::Clean::JSON;
 
+our $DATE = '2015-03-26'; # DATE
+our $VERSION = '0.21'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
 use parent qw(Data::Clean::Base);
 
-our $VERSION = '0.20'; # VERSION
-
 sub new {
     my ($class, %opts) = @_;
     $opts{DateTime}  //= [call_method => 'epoch'];
@@ -40,7 +41,7 @@ Data::Clean::JSON - Clean data so it is safe to output to JSON
 
 =head1 VERSION
 
-This document describes version 0.20 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2014-12-10.
+This document describes version 0.21 of Data::Clean::JSON (from Perl distribution Data-Clean-JSON), released on 2015-03-26.
 
 =head1 SYNOPSIS
 
@@ -82,7 +83,7 @@ If C<LOG_CLEANSER_CODE> environment is set to true, the generated cleanser code
 will be logged using L<Log::Any> at trace level. You can see it, e.g. using
 L<Log::Any::App>:
 
- % LOG_CLEANSER_CODE=1 TRACE=1 perl -MLog::Any::App -MData::Clean::JSON \
+ % LOG=1 LOG_CLEANSER_CODE=1 TRACE=1 perl -MLog::Any::App -MData::Clean::JSON \
    -e'$c=Data::Clean::JSON->new; ...'
 
 =head1 METHODS
@@ -192,7 +193,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
